==> traintrain_0.5.1-1.tar.gz: traintrain-0.5.1/src/opt/traintrain/model/RideModel.py <==
﻿#!/usr/bin/python
# -*- coding: utf-8 -*-

from utils.DebugLog import DebugLog
from PyQt4 import QtCore

class Ride:
   def __init__(self):
      self.train = ''
      self.heure = ''
      self.destination = ''
      self.voie = ''
      self.error = ''

   def setTrain(self, train):
      self.train = train

   def setHeure(self, heure):
      self.heure = heure

   def setDestination(self, destination):
      self.destination = destination

   def setVoie(self, voie):
      self.voie = voie

   def setError(self, error):
      self.error = error

   def __str__(self):
      return unicode('Train: %s, Heure: %s, Destination: %s, Voie: %s'%(self.train, self.heure, self.destination, self.voie))

class RideModel(QtCore.QObject):
   def __init__(self, id):
      DebugLog("RideModel::__init__")
      QtCore.QObject.__init__(self)

      self.rides = []
      self.perturbations = []
      self.id = id
      self.read=0
      self.total=0
      self.progress=0.0

   def __str__(self):
      s = u''
      for ride in self.getRides():
         s += unicode(ride)+u'\n'
      return s
      
   def Clear(self):
      DebugLog("RideModel::Clear")
      self.rides = []
      self.perturbations = []

   def getIcon(self):
      return self.icon

   def getTitle(self):
      return self.title

   def getRides(self):
      return self.rides

   def getPerturbations(self):
      return self.perturbations

   def ClearPerturbations(self):
      self.perturbations = []

   def AddPerturbation(self, perturbation):
      self.perturbations.append(perturbation)

   def setIconTitle(self, icontitle):
      self.icon, self.title = icontitle

   def addRide(self, ride):
      self.rides.append(ride)

   def SetInfo(self, stype, text):
      self.emit(QtCore.SIGNAL('info'), stype, text)

   def SetProgress(self, read, total):
      self.read = read
      self.total = total
      if total>0:
         self.progress=float(100.0*read)/float(total)
      self.emit(QtCore.SIGNAL('progress'))

==> traintrain_0.6.1-2.tar.gz: traintrain-0.6.1/src/opt/traintrain/model/RideModel.py <==
﻿#!/usr/bin/python
# -*- coding: utf-8 -*-

from utils.DebugLog import DebugLog
from PyQt4 import QtCore

class Ride:
   def __init__(self):
      self.train = ''
      self.heure = ''
      self.destination = ''
      self.voie = ''
      self.error = ''
      self.noTrain = False

   def setNoTrain(self, b):
      self.noTrain = b
      
   def setTrain(self, train):
      self.train = train

   def setHeure(self, heure):
      self.heure = heure

   def setDestination(self, destination):
      self.destination = destination

   def setVoie(self, voie):
      self.voie = voie

   def setError(self, error):
      self.error = error

   def __str__(self):
      return unicode('Train: %s, Heure: %s, Destination: %s, Voie: %s'%(self.train, self.heure, self.destination, self.voie))

class RideModel(QtCore.QObject):
   def __init__(self, id):
      DebugLog("RideModel::__init__")
      QtCore.QObject.__init__(self)

      self.rides = []
      self.perturbations = []
      self.id = id
      self.read=0
      self.total=0
      self.progress=0.0

   def __str__(self):
      s = u''
      for ride in self.getRides():
         s += unicode(ride)+u'\n'
      return s
      
   def Clear(self):
      DebugLog("RideModel::Clear")
      self.rides = []
      self.perturbations = []

   def getUrl(self):
      t, l, s = self.icon
      rul = ''
      if t=='M':
         url = u'http://fr.wikipedia.org/wiki/Ligne_%s_du_métro_de_Paris'%l
      elif t=='R':
         url = "http://fr.wikipedia.org/wiki/Ligne_%s_du_RER_d'Ile-de-France"%l

      return QtCore.QUrl(url)
      
   def getIcon(self):
      return self.icon

   def getTitle(self):
      return self.title

   def getRides(self):
      return self.rides

   def getPerturbations(self):
      return self.perturbations

   def ClearPerturbations(self):
      self.perturbations = []

   def AddPerturbation(self, perturbation):
      self.perturbations.append(perturbation)

   def setIconTitle(self, icontitle):
      self.icon, self.title = icontitle

   def addRide(self, ride):
      self.rides.append(ride)

   def SetInfo(self, stype, text):
      self.emit(QtCore.SIGNAL('info'), stype, text)

   def SetProgress(self, read, total):
      self.read = read
      self.total = total
      if total>0:
         self.progress=float(100.0*read)/float(total)
      self.emit(QtCore.SIGNAL('progress'))
